<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;

class RelSinteseFaturamento {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function getParams($conditions){
        $params = array(
         	":CDFILIAL" => $conditions['CDFILIAL'],
         	":CDLOJA" => $conditions['CDLOJA'],
         	":TCDLOJA" => $conditions['TCDLOJA'],
         	":DATAINI" => $conditions['DATAINI'],
         	":DATAFIN" => $conditions['DATAFIN'],
         	":MODALIDADE" => $conditions['MODALIDADE'],
         	":NRORG" => $conditions['NRORG'],
         	":FLAGBALTAA" => $conditions['FLAGBALTAA']
 		);
 		return $params;
 		
    }
    
    public function findRel($conditions) {
        $params = $this->getParams($conditions); 
        $query = $this->getSQL($conditions['TIPORELATORIO'], $conditions['RELATORIO']);
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }
     
    public function findRelTotPorMod($conditions) {
        $params = $this->getParams($conditions);
        $result = $this->entityManager->getConnection()->fetchAll(self::GET_FATURAMENTO_TOTAL_POR_MODALIDADE, $params);
        $array = [];
        
        foreach ($result as $value) {
            $array[$value['CDFILIAL']]['CDFILIAL'] = $value['CDFILIAL'];
            $array[$value['CDFILIAL']]['CODFILIAL'] = $value['CODFILIAL'];
            $array[$value['CDFILIAL']][$value['NMMODALIDADE']] = $value['NMMODALIDADE'];
            $array[$value['CDFILIAL']][$value['NMMODALIDADE'].'_VALOR_VENDIDO'] = $value['VALOR_VENDIDO'];
            if (array_key_exists ('VRDESCONTO', $array[$value['CDFILIAL']])) {
               $array[$value['CDFILIAL']]['VRDESCONTO'] = $array[$value['CDFILIAL']]['VRDESCONTO'] + $value['VRDESCONTO'];
            }else{
                $array[$value['CDFILIAL']]['VRDESCONTO'] = $value['VRDESCONTO'];
            }
        }
        $indexArray = [];
        foreach ($array as $value) {
            array_key_exists('BALCAO_VALOR_VENDIDO', $value)  ? : $value['BALCAO_VALOR_VENDIDO'] = 0;
            array_key_exists('COMANDA_VALOR_VENDIDO', $value) ? : $value['COMANDA_VALOR_VENDIDO'] = 0;
            array_key_exists('DELIVERY_VALOR_VENDIDO', $value) ? : $value['DELIVERY_VALOR_VENDIDO'] = 0;
            array_key_exists('MESA_VALOR_VENDIDO', $value) ? : $value['MESA_VALOR_VENDIDO'] = 0;
            array_key_exists('TAA_VALOR_VENDIDO', $value) ? : $value['TAA_VALOR_VENDIDO'] = 0;
            array_key_exists('DRIVE_THRU_VALOR_VENDIDO', $value) ? : $value['DRIVE_THRU_VALOR_VENDIDO'] = 0; 
            array_push($indexArray, $value);
        }
        return $indexArray;
    }
    
    public function findFaturamentoDeliveryAnaliticoGeral($params){
 		return $this->entityManager->getConnection()->fetchAll(self::GET_FATURAMENTODELIVERY_GERAL_ANALITICO, $params);
    }
    
    public function findFaturamentoDeliverySinteticoGeral($params){
 		return $this->entityManager->getConnection()->fetchAll(self::GET_FATURAMENTODELIVERY_GERAL_SINTETICO , $params);
    }
    
    public function findFaturamentoDeliveryAnaliticoDia($params){
        return $this->entityManager->getConnection()->fetchAll(self::GET_FATURAMENTODELIVERY_DIA_ANALITICO, $params);
    }
    
    public function findFaturamentoDeliverySinteticoDia($params){
        return $this->entityManager->getConnection()->fetchAll(self::GET_FATURAMENTODELIVERY_DIA_SINTETICO, $params);
    }
    
    public function buildParamsFaturamento($conditions, $modalidade){
        $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
        
        if(!array_key_exists('CDLOJA', $conditions)) {
            $conditions['CDLOJA'] = '';
            $conditions['TCDLOJA'] = 'T';
        } else {
            $conditions['CDLOJA'] = implode('_', $conditions['CDLOJA']);
            $conditions['TCDLOJA'] = '';
        }
        if(!array_key_exists('MODALIDADE', $conditions)) {
            $conditions['MODALIDADE'] = $modalidade;
        } else {
            $conditions['MODALIDADE'] = implode('_', $conditions['MODALIDADE']);
        }
        $conditions['FLAGBALTAA'] = 'N';
        $conditions['FLAGBALTAA'] = (strpos($conditions['MODALIDADE'], 'BAL') !== false ? (strpos($conditions['MODALIDADE'], 'TAA') !== false ? 'N' : 'S') : 'N');
        if(array_key_exists('DTENTRVENDA', $conditions)) {
            $conditions['DATAINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['DATAFIN'] = $conditions['DTENTRVENDA'][1];
            unset($conditions['DTENTRVENDA']);
        }
        return $conditions;
    }
    
    public function reorderResultsbyDate($result){
        
        $currentFilial = $result[0]['CODIGOFILIAL']; 
        $data = $result[0]['DATA']; 
        
        $i = 0;
        
        foreach($result as $index => $res) {
            
            if($res['CODIGOFILIAL'] === $currentFilial) {
                if($data === $res['DATA']) {
                    $result[$index]['DATA'] = str_pad(($i + 1), 3, "0", STR_PAD_LEFT) . ' - ' . $result[$index]['DATA']; 
                } else {
                    $data = $result[$index]['DATA'];
                    $i++;
                    $result[$index]['DATA'] = str_pad(($i + 1), 3, "0", STR_PAD_LEFT) . ' - ' . $result[$index]['DATA']; 
                }
            } else {
                $currentFilial = $res['CODIGOFILIAL'];
                $i = -1;
                
                if($data === $res['DATA']) {
                    $result[$index]['DATA'] = str_pad(($i + 1), 3, "0", STR_PAD_LEFT) . ' - ' . $result[$index]['DATA']; 
                } else {
                    $data = $result[$index]['DATA'];
                    $i++;
                    $result[$index]['DATA'] = str_pad(($i + 1), 3, "0", STR_PAD_LEFT) . ' - ' . $result[$index]['DATA']; 
                }
            }
        }
        
        return $result;
    }
    
    public function getSQL($modalidade = 'A', $tipoRelatorio = 'GERAL'){
        if($modalidade == 'A' && $tipoRelatorio == 'GERAL'){
            $GROUP = self::GROUP_MOD;
            $GROUP_BY = "TAB1.CDFILIAL,
            		 TAB1.NMFILIAL,		 
            		 TAB1.MODALIDADE";
            $ORDER_BY = "TAB1.CDFILIAL,
            		 TAB1.NMFILIAL,		 
            		 TAB1.MODALIDADE";
        }else if($modalidade == 'S' && $tipoRelatorio == 'GERAL'){
            $GROUP = self::GROUP_MOD_TODOS;
            $GROUP_BY = "TAB1.CDFILIAL,
            		 TAB1.NMFILIAL";
            $ORDER_BY = "TAB1.CDFILIAL,
            		 TAB1.NMFILIAL";
        }else if($tipoRelatorio == 'DIA'){
            $GROUP_BY = "TAB1.CDFILIAL,
            		 TAB1.NMFILIAL,		 
            		 TAB1.DTENTRVENDA,
            		 TAB1.MODALIDADE";
            		 
            $ORDER_BY = "TAB1.CDFILIAL,
            		 TAB1.NMFILIAL,		 
            		 TAB1.DTENTRVENDA,
            		 TAB1.MODALIDADE
            		 ";
            		 
            if($modalidade == 'A' || $modalidade == 'D'){
                $GROUP = self::GROUP_MOD_DIA_ANA;    
            }else if($modalidade == 'S'){
                $GROUP = self::GROUP_MOD_DIA_SIN;
            }
        }
        
        $query = "
        SELECT FINALTAB.CDFILIAL || ' - ' || FINALTAB.NMFILIAL AS CODFILIAL, FINALTAB.CDFILIAL||' - '||'Periodo:' || :DATAINI || ' a ' || :DATAFIN AS PERIODO,  FINALTAB.CDFILIAL AS CODIGOFILIAL, ".$GROUP."FINALTAB.*, 

            CASE 
            	WHEN FINALTAB.NROPESSOAS > 0 THEN TRUNC(FINALTAB.VALOR_TOTAL/FINALTAB.NROPESSOAS, 2) 
            	ELSE 0
            END AS TICKETMEDIO,
            
            CASE 
            	WHEN FINALTAB.NROPESSOAS > 0 THEN TRUNC(FINALTAB.VALOR_CAL_TKGIRIA/FINALTAB.NROPESSOAS, 2)
            	ELSE 0
            END AS TICKETMEDIOGIRA
            
             FROM (
            
            
            /*NESSA QUERY PRINCIPAL QUE FARA O AGRUPAMENTO, FALTA CALCULOS DOS TICKETS MEDIOS*/
            
            SELECT   ".$GROUP_BY.", 		 
            		 SUM(NVL(TAB1.VALOR_VENDIDO, 0) + (NVL(TAB1.VRACRESCIMO, 0) - NVL(TAB2.VALOR_TOTAL, 0) - NVL(TAB3.VALOR_TOTAL, 0))) AS VALOR_CAL_TKGIRIA,
            		 SUM(NVL(TAB1.VALOR_TOTAL, 0)) AS VALOR_TOTAL, 
            		 SUM(NVL(TAB1.VALOR_VENDIDO, 0) + NVL(TAB3.VALOR_TOTAL, 0)) AS VALOR_VENDIDO, 
            		 SUM(NVL(TAB1.VRDESCONTO, 0)) AS VRDESCONTO, 
            		 SUM(NVL(TAB1.VRREPIQUE, 0)) AS VRREPIQUE,
                     SUM(NVL(TAB3.VALOR_TOTAL, 0)) AS VRACRESCIMO, 
            		 SUM((NVL(TAB1.VRACRESCIMO, 0) - NVL(TAB2.VALOR_TOTAL, 0) - NVL(TAB3.VALOR_TOTAL, 0))) AS VRACRESCIMOANTIGO, 
            		 SUM(NVL(TAB2.VALOR_TOTAL, 0)) AS VRGORJETA,
                     SUM(NVL(TAB1.VRCANCELAMENTO, 0)) AS VRCANCELAMENTO, 
                     SUM(NVL(TAB1.VALOR_VENDIDO, 0) + NVL(TAB3.VALOR_TOTAL, 0) + NVL(TAB1.VRDESCONTO, 0)) AS VRBRUTO, 
                     SUM(NVL(TAB1.VALOR_TOTAL, 0) - NVL(TAB3.VALOR_TOTAL, 0) - NVL(TAB2.VALOR_TOTAL, 0) - (NVL(TAB1.VRACRESCIMO, 0) - NVL(TAB2.VALOR_TOTAL, 0) - NVL(TAB3.VALOR_TOTAL, 0)) - NVL(TAB1.VRREPIQUE, 0)) AS VRLIQUIDO, 
            		 SUM(TAB1.NROPESSOAS) AS NROPESSOAS,		 
                     SUM(NVL(TAB1.VALOR_VENDIDO, 0) + (NVL(TAB1.VRACRESCIMO, 0) - NVL(TAB2.VALOR_TOTAL, 0) - NVL(TAB3.VALOR_TOTAL, 0))) AS FATURAMENTOGIRA, 
                     SUM((NVL(TAB1.VALOR_VENDIDO, 0) - NVL(TAB1.VRREPIQUE, 0)) + NVL(TAB1.VRACRESCIMO, 0))  AS VRTOTAL,		 
            		 SUM(TAB1.QTD_TOTAL) AS QTD_TOTAL
                FROM (
                        
                      ".self::TOTAL_MOD_DIA."  
            
            		) TAB1
                LEFT JOIN (
            	
            		".self::TOTAL_GORJETA."  
            	
            	) TAB2
                       ON TAB1.CDFILIAL = TAB2.CDFILIAL
                       AND TAB1.DTENTRVENDA = TAB2.DTENTRVENDA
            		   AND TAB1.MODALIDADE = TAB2.MODALIDADE
                LEFT JOIN (		
            		
            		".self::TOTAL_TX_ENTREGA."  
            	    
            	
            	) TAB3
                         ON TAB1.CDFILIAL = TAB3.CDFILIAL
                        AND TAB1.DTENTRVENDA = TAB3.DTENTRVENDA
            			AND TAB1.MODALIDADE = TAB3.MODALIDADE
            	GROUP BY 
            	     ".$GROUP_BY." 
            	ORDER BY      
            	     ".$ORDER_BY.") FINALTAB ";
        
        return strval(trim($query));;
    }
    
    const TOTAL_MOD_DIA = "
    
		/*VALOR TOTAL SUM POR MODADLIDADE E DIA */

		SELECT CDFILIAL, NMFILIAL, MODALIDADE, DTENTRVENDA, SUM(VALOR_VENDIDO) AS VALOR_VENDIDO, SUM(VRDESCONTO) AS VRDESCONTO,
						 SUM(VRACRESCIMO) AS VRACRESCIMO, SUM(VRCANCELAMENTO) AS VRCANCELAMENTO, SUM(VALOR_TOTAL) AS VALOR_TOTAL, SUM(QTD_TOTAL) AS QTD_TOTAL,
						 SUM(VRREPIQUE) AS VRREPIQUE, SUM(NROPESSOAS) AS NROPESSOAS

		FROM (


				/*VALOR REPIQUE E O NºPESSOAS ATENDIDAS por DIA/MODALIDADE -> Só aceitas*/


				SELECT       CDFILIAL,
							 NMFILIAL,
							 CDCAIXA,
							 MODALIDADE,
							 DTENTRVENDA,
							 SUM(VRREPIQUE) AS VRREPIQUE,
							 SUM(NROPESSOAS) AS NROPESSOAS,
							 0 AS VRDESCONTO,
							 0 AS VRACRESCIMO,
							 0 AS VALOR_VENDIDO,
							 0 AS VALOR_TOTAL,
							 0 AS QTD_TOTAL,
							 0 AS VRCANCELAMENTO			 
					  FROM
						(WITH FLC AS
						   (SELECT DISTINCT V.CDFILIAL,
											V.CDLOJA,
											V.CDCAIXA,
											L.IDCOMISVENDA,
											V.NMFILIAL
							FROM V_FILIALLOJACAIXA V,
								 LOJA L
							WHERE ((INSTR(:CDLOJA, V.CDFILIAL||V.CDLOJA) > 0) OR (:TCDLOJA = 'T'))
							  AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
							  AND V.CDFILIAL = L.CDFILIAL
							  AND V.CDLOJA = L.CDLOJA) SELECT V.CDFILIAL,
															  FLC.NMFILIAL,
															  V.NRSEQVENDA,
															  CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
           WHEN 'DLV' THEN 'DELIVERY'
           WHEN 'MES' THEN 'MESA'
           WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
           WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
           WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE THRU' ELSE 'COMANDA' END) 
           WHEN 'AJU' THEN 'OUTROS'
           ELSE 'OUTROS'
         END AS MODALIDADE,
															  SUM(NVL(V.NRPESMESAVENDA, 1)) AS NROPESSOAS,
															  SUM(NVL(V.VRREPIQUEVENDA, 0)) AS VRREPIQUE, 
															  V.DTENTRVENDA,
															  V.CDCAIXA
						 FROM VENDA V,
							  FLC
						 WHERE V.CDFILIAL = FLC.CDFILIAL
						   AND V.CDCAIXA = FLC.CDCAIXA
						   AND V.CDLOJA = FLC.CDLOJA
						   AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN           
						   AND V.IDSITUVENDA IN(CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
													WHEN 'AJU' THEN V.IDSITUVENDA
													ELSE 'O'
												END)
						   AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
						   AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)
						 GROUP BY V.CDFILIAL,
								  FLC.NMFILIAL,
								  V.NRSEQVENDA,
								  V.IDORIGEMVENDA,
								  V.DTENTRVENDA,
								  V.CDCAIXA)
					  GROUP BY CDFILIAL,
							   NMFILIAL,
							   CDCAIXA,
							   MODALIDADE,
							   DTENTRVENDA


				/*ITEMVENDA UNIAO DOS DOIS ABAIXO*/
							   
				/*VALORES DE ACRESCIMO, DESCONTO, VALOR_VENDIDO, VALOR_TOTAL, QTD_TOTAL DIA/MODALIDADE -> Só aceitas*/

				UNION

				SELECT CDFILIAL, NMFILIAL, CDCAIXA, MODALIDADE, DTENTRVENDA, 0 AS VRREPIQUE,
							 0 AS NROPESSOAS, SUM(VRDESCONTO) AS VRDESCONTO, SUM(VRACRESCIMO) AS VRACRESCIMO, SUM(VALOR_VENDIDO) AS VALOR_VENDIDO, SUM(VALOR_TOTAL) AS VALOR_TOTAL, SUM(QTD_TOTAL) AS QTD_TOTAL, 0 AS VRCANCELAMENTO
				FROM (
						WITH FLC AS 
						   (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA, V.NMFILIAL
							   FROM V_FILIALLOJACAIXA V, LOJA L
							  WHERE ((INSTR(:CDLOJA, V.CDFILIAL||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
								AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
								AND V.CDFILIAL = L.CDFILIAL
								AND V.CDLOJA = L.CDLOJA)
						SELECT ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, V.DTENTRVENDA,CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
           WHEN 'DLV' THEN 'DELIVERY'
           WHEN 'MES' THEN 'MESA'
           WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
           WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
           WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE THRU' ELSE 'COMANDA' END) 
           WHEN 'AJU' THEN 'OUTROS'
           ELSE 'OUTROS'
         END AS MODALIDADE, FLC.NMFILIAL, SUM(TRUNC(NVL(ITV.VRDESITVEND, 0), 2)) AS VRDESCONTO, 
							  CASE V.IDSITUVENDA WHEN 'C' THEN 0 ELSE SUM(TRUNC(NVL(ITV.VRACRITVEND, 0), 2)) END AS VRACRESCIMO,
							  CASE V.IDSITUVENDA WHEN 'C' THEN 0 ELSE SUM(TRUNC(ITV.QTPRODVEND * (ITV.VRUNITVEND + NVL(ITV.VRUNITVENDCL,0)),2) - NVL(ITV.VRDESITVEND, 0)) END AS VALOR_VENDIDO,
							  SUM(TRUNC(ITV.QTPRODVEND * (ITV.VRUNITVEND + NVL(ITV.VRUNITVENDCL,0)),2) - NVL(ITV.VRDESITVEND, 0) + NVL(ITV.VRACRITVEND,0)) AS VALOR_TOTAL,
							  SUM(ITV.QTPRODVEND) AS QTD_TOTAL 
						 FROM VENDA V, FLC, ITEMVENDA ITV  
						WHERE V.CDFILIAL = FLC.CDFILIAL
						  AND V.CDCAIXA = FLC.CDCAIXA
						  AND V.CDLOJA = FLC.CDLOJA
						  AND V.CDFILIAL = ITV.CDFILIAL
						  AND V.CDCAIXA = ITV.CDCAIXA
						  AND V.NRSEQVENDA = ITV.NRSEQVENDA                                      
						  AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN                                                                            
						  AND V.IDSITUVENDA IN(CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
												WHEN 'AJU' THEN V.IDSITUVENDA
												ELSE 'O'
											END)
						  AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
						  AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)
						GROUP BY ITV.CDFILIAL, ITV.CDCAIXA, V.IDORIGEMVENDA, ITV.NRSEQVENDA, V.IDSITUVENDA, V.DTENTRVENDA, FLC.NMFILIAL
					 ) 
				GROUP BY CDFILIAL, NMFILIAL, CDCAIXA, MODALIDADE, DTENTRVENDA

				UNION

				/*VALORES DE CANCELAMENTO -> Itens Cancelados e vendas canceladas */

				SELECT CDFILIAL, NMFILIAL, CDCAIXA, MODALIDADE, DTENTRVENDA,
						0 AS VRREPIQUE,
						0 AS NROPESSOAS,
						0 AS VRDESCONTO,
						0 AS VRACRESCIMO,
						0 AS VALOR_VENDIDO,
						0 AS VALOR_TOTAL,
						0 AS QTD_TOTAL,
						SUM(VRCANCELAMENTO) AS VRCANCELAMENTO					 		
									FROM (

											WITH FLC AS 
											   (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA, V.NMFILIAL
												   FROM V_FILIALLOJACAIXA V, LOJA L
												  WHERE ((INSTR(:CDLOJA, V.CDFILIAL||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
													AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
													AND V.CDFILIAL = L.CDFILIAL
													AND V.CDLOJA = L.CDLOJA)
													SELECT ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
           WHEN 'DLV' THEN 'DELIVERY'
           WHEN 'MES' THEN 'MESA'
           WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
           WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
           WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE THRU' ELSE 'COMANDA' END) 
           WHEN 'AJU' THEN 'OUTROS'
           ELSE 'OUTROS'
         END AS MODALIDADE, V.DTENTRVENDA,	FLC.NMFILIAL,		 
													 SUM(TRUNC(ITV.QTPRODVEND * (ITV.VRUNITVEND + NVL(ITV.VRUNITVENDCL,0)),2) + NVL(ITV.VRACRITVEND,0) ) AS VRCANCELAMENTO,
													 SUM(ITV.QTPRODVEND) AS QTD_TOTAL 
													FROM VENDA V, FLC, ITEMVENDA ITV                                 
													WHERE V.CDFILIAL = ITV.CDFILIAL
													 AND V.CDCAIXA = ITV.CDCAIXA
													 AND V.NRSEQVENDA = ITV.NRSEQVENDA		 
													 AND V.CDFILIAL = FLC.CDFILIAL
													 AND V.CDCAIXA = FLC.CDCAIXA
													 AND V.CDLOJA = FLC.CDLOJA
													 AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
													 AND V.IDSITUVENDA = 'C'		 
													 AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
													 AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)
													GROUP BY ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, V.IDORIGEMVENDA, V.DTENTRVENDA, FLC.NMFILIAL
														
											UNION			


											SELECT ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
           WHEN 'DLV' THEN 'DELIVERY'
           WHEN 'MES' THEN 'MESA'
           WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
           WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
           WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE THRU' ELSE 'COMANDA' END) 
           WHEN 'AJU' THEN 'OUTROS'
           ELSE 'OUTROS'
         END AS MODALIDADE, V.DTENTRVENDA, FLC.NMFILIAL,
													 SUM(TRUNC(ITV.QTPRODVENDC * (ITV.VRUNITVENDC + NVL(ITV.VRUNITVENCLC,0)),2) + NVL(ITV.VRACRITVENDC,0) ) AS VRCANCELAMENTO,
													 SUM(ITV.QTPRODVENDC) AS QTD_TOTAL 
												FROM VENDA V, (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA, V.NMFILIAL
												   FROM V_FILIALLOJACAIXA V, LOJA L
												  WHERE ((INSTR(:CDLOJA, V.CDFILIAL ||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
													AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
													AND V.CDFILIAL = L.CDFILIAL
													AND V.CDLOJA = L.CDLOJA) FLC, ITVENDACAN ITV
											   WHERE V.CDFILIAL = ITV.CDFILIAL
												 AND V.CDCAIXA = ITV.CDCAIXA
												 AND V.NRSEQVENDA = ITV.NRSEQVENDA	 
												 AND V.CDFILIAL = FLC.CDFILIAL
												 AND V.CDCAIXA = FLC.CDCAIXA
												 AND V.CDLOJA = FLC.CDLOJA
												 AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN   
												 AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
												 AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)												 
											   GROUP BY ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, V.IDORIGEMVENDA, V.DTENTRVENDA, FLC.NMFILIAL
										)
				GROUP BY CDFILIAL, NMFILIAL, CDCAIXA, MODALIDADE, DTENTRVENDA
				) VENDMODDIA

				GROUP BY CDFILIAL, NMFILIAL, MODALIDADE, DTENTRVENDA
				ORDER BY CDFILIAL, NMFILIAL, DTENTRVENDA, MODALIDADE
    ";
    
    
    const TOTAL_GORJETA = "
        /*CALCULO GORJETA QUANDO PRODUTO TRATADO/PARAMETRIZADO PARA TAL CALCULO, NAO PODE SER NA MODALIDADE DELIVERY, SO ACEITAS */

		SELECT TB2.CDFILIAL,'', TB2.DTENTRVENDA, TB2.MODALIDADE, SUM(TB2.VALOR_TOTAL) AS VALOR_TOTAL, 0
		FROM ( SELECT V.CDFILIAL,'', V.DTENTRVENDA,CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
           WHEN 'DLV' THEN 'DELIVERY'
           WHEN 'MES' THEN 'MESA'
           WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
           WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
           WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE THRU' ELSE 'COMANDA' END) 
           WHEN 'AJU' THEN 'OUTROS'
           ELSE 'OUTROS'
         END AS MODALIDADE, SUM(I.QTPRODVEND) AS QTD_TOTAL, NVL(SUM(NVL(I.VRACRITVEND,0)), 0) AS VALOR_TOTAL, 0
			FROM ITEMVENDA I, (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA, L.CDPRODTAXASERV, L.IDTRATTAXASERV
				   FROM V_FILIALLOJACAIXA V, LOJA L
				  WHERE ((INSTR(:CDLOJA, V.CDFILIAL ||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
					AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
					AND V.CDFILIAL = L.CDFILIAL
					AND V.CDLOJA = L.CDLOJA) FLC, VENDA V
			WHERE V.NRSEQVENDA  = I.NRSEQVENDA      
			 AND V.CDCAIXA     = I.CDCAIXA
			 AND V.CDFILIAL    = I.CDFILIAL                                                                  
			 AND V.CDFILIAL = FLC.CDFILIAL
			 AND V.CDCAIXA = FLC.CDCAIXA
			 AND V.CDLOJA = FLC.CDLOJA                                
			 AND I.CDPRODUTO   = FLC.CDPRODTAXASERV                               
			 AND FLC.IDCOMISVENDA IN ('S', 'G')      
			 AND FLC.IDTRATTAXASERV = 'P'                             
			 AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
			 AND V.IDSITUVENDA = 'O'               
			 AND SUBSTR(V.IDORIGEMVENDA, 0, 3) <> 'DLV'   
             AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
			 AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)			 
			GROUP BY V.CDFILIAL, V.DTENTRVENDA, V.IDORIGEMVENDA) TB2
		GROUP BY TB2.CDFILIAL, TB2.DTENTRVENDA, TB2.MODALIDADE
    ";
    
    const TOTAL_TX_ENTREGA = "
        /*CALCULO TAXA DE ENTREGA QUANDO PRODUTO TRATADO/PARAMETRIZADO PARA TAL CALCULO, MODALIDADE DELIVERY, SO ACEITAS */


		SELECT CDFILIAL, '', DTENTRVENDA, MODALIDADE, SUM(QTD_TOTAL) AS QTD_TOTAL, SUM(VALOR_TOTAL) AS VALOR_TOTAL, 0 
				FROM (
					   SELECT V.CDFILIAL,  '', V.DTENTRVENDA, CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
           WHEN 'DLV' THEN 'DELIVERY'
           WHEN 'MES' THEN 'MESA'
           WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
           WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
           WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE THRU' ELSE 'COMANDA' END) 
           WHEN 'AJU' THEN 'OUTROS'
           ELSE 'OUTROS'
         END AS MODALIDADE, SUM(I.QTPRODVEND) AS QTD_TOTAL, 
							  NVL(SUM(NVL(I.VRACRITVEND,0))- SUM(NVL(V.VRREPIQUEVENDA,0)), 0)AS VALOR_TOTAL, 0
						FROM ITEMVENDA I, (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA, L.CDPRODTAXASERV, L.IDTRATTAXASERV, L.IDTRATTAXAENTR, L.CDPRODTAXAENTR
										   FROM V_FILIALLOJACAIXA V, LOJA L
										  WHERE ((INSTR(:CDLOJA, V.CDFILIAL ||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
											AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
											AND V.CDFILIAL = L.CDFILIAL
											AND V.CDLOJA = L.CDLOJA) FLC, VENDA V
						WHERE V.NRSEQVENDA  = I.NRSEQVENDA      
						  AND V.CDCAIXA     = I.CDCAIXA
						  AND V.CDFILIAL    = I.CDFILIAL                                                                  
						  AND V.CDFILIAL = FLC.CDFILIAL
						  AND V.CDCAIXA = FLC.CDCAIXA
						  AND V.CDLOJA = FLC.CDLOJA                                
						  AND I.CDPRODUTO   = FLC.CDPRODTAXAENTR        
						  AND FLC.IDTRATTAXAENTR = 'P'              
						  AND SUBSTR(V.IDORIGEMVENDA, 0, 3) = 'DLV'                                            
						  AND V.IDSITUVENDA = 'O'                                        
						  AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN   
						  AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
						  AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)						  
						GROUP BY V.CDFILIAL, V.DTENTRVENDA, V.IDORIGEMVENDA)
						GROUP BY CDFILIAL, DTENTRVENDA, MODALIDADE
	
    
    ";
    
    const GROUP_MOD_DIA_ANA = "
         TO_CHAR(FINALTAB.DTENTRVENDA, 'DD/MM/YYYY') AS DATA,
         FINALTAB.MODALIDADE AS NMMODALIDADE, ";
         
    const GROUP_MOD_DIA_SIN = "
         TO_CHAR(FINALTAB.DTENTRVENDA, 'DD/MM/YYYY') AS DATA,
         'TODOS' AS NMMODALIDADE, ";
         
    const GROUP_MOD = "
         FINALTAB.MODALIDADE AS NMMODALIDADE, ";
   
   const GROUP_MOD_TODOS = "'TODOS' AS NMMODALIDADE, ";
   
  
    const GET_FATURAMENTODELIVERY_GERAL_ANALITICO = "
      SELECT TAB1.CDFILIAL || ' - ' || TAB1.NMFILIAL AS CODFILIAL,
             TAB1.CDFILIAL AS CODIGOFILIAL,
             TAB1.MODALIDADE AS MODALIDADE, 
             NVL(TAB1.VALOR_TOTAL, 0) - NVL(TAB2.VALOR_TOTAL, 0) AS VRVENDA,
             NVL(TAB2.VALOR_TOTAL, 0) AS VRTXENTREGA,
             NVL(TAB1.VALOR_TOTAL, 0) AS VRTOTAL,
             TAB1.NROPESSOAS,
             TRUNC((NVL(TAB1.VALOR_TOTAL, 0))/TAB1.NROPESSOAS, 2) AS TICKETMEDIO
        FROM (SELECT VENDA.CDFILIAL,
                     VENDA.NMFILIAL,
                     VENDA.MODALIDADE,
                     SUM(ITEMVENDA.VALOR_TOTAL) AS VALOR_TOTAL,
                     VENDA.NROPESSOAS AS NROPESSOAS
                FROM (SELECT CDFILIAL, NMFILIAL, NRORG, MODALIDADE, SUM(NROPESSOAS) AS NROPESSOAS 
                       FROM (SELECT V.CDFILIAL, F.NMFILIAL, V.NRSEQVENDA,
                                    DECODE(NVL(V.IDORIGEMVENDA, 'DLV_OUT'), 'DLV_SIT', 'Site/App (Teknisa)', 'DLV_APP', 'Aplicativo', 'DLV_CAL', 'Callcenter', 'DLV_INT', 'Site/Integração', 'DLV_FOS', 'ForSale', 'DLV_SAT', 'ForSale', 'DLV_FNC', 'ForSale', 'DLV_IFO', 'iFood', 'DLV_PJA', 'Pedidos Já', 'DLV_SPO', 'Spoon Rocket', 'DLV_IOS', 'Apple', 'DLV_ADR', 'Android', 'DLV_TAA', 'Terminal de Auto Atendimento', 'DLV_ABF', 'Abra Food', 'DLV_ONY', 'Onyo', 'DLV_WZP', 'Whats App', 'DLV_UBR', 'Uber Eats', 'DLV_YAN', 'Yandeh', 'DLV_RAP', 'Rappi', 'DLV_OUT', 'Outros', 'Outros') AS MODALIDADE,
                                    SUM(NVL(V.NRPESMESAVENDA, 1)) AS NROPESSOAS,
                                    V.NRORG, V.CDCAIXA
                               FROM VENDA V
                               JOIN FILIAL F
                                 ON V.CDFILIAL = F.CDFILIAL
                                AND V.NRORG   = F.NRORG
                              WHERE INSTR(:CDFILIAL, V.CDFILIAL) > 0
                                AND ((INSTR(:CDLOJA, V.CDFILIAL ||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
                                AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                                AND V.IDSITUVENDA = 'O'
                                AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0
                                AND V.NRORG = :NRORG
                              GROUP BY V.CDFILIAL, F.NMFILIAL, V.NRSEQVENDA, V.IDORIGEMVENDA, V.NRORG, V.CDCAIXA
                            )
                      GROUP BY CDFILIAL, NMFILIAL, MODALIDADE, NRORG
                     ) VENDA
                JOIN (
                      SELECT CDFILIAL, MODALIDADE, CDCAIXA, NRORG, SUM(VALOR_TOTAL) AS VALOR_TOTAL 
                        FROM (
                              SELECT ITV.CDFILIAL,
                                     ITV.CDCAIXA,
                                     ITV.NRSEQVENDA,                
                                     DECODE(NVL(V.IDORIGEMVENDA, 'DLV_OUT'), 'DLV_SIT', 'Site/App (Teknisa)', 'DLV_APP', 'Aplicativo', 'DLV_CAL', 'Callcenter', 'DLV_INT', 'Site/Integração', 'DLV_FOS', 'ForSale', 'DLV_SAT', 'ForSale', 'DLV_FNC', 'ForSale', 'DLV_IFO', 'iFood', 'DLV_PJA', 'Pedidos Já', 'DLV_SPO', 'Spoon Rocket', 'DLV_IOS', 'Apple', 'DLV_ADR', 'Android', 'DLV_TAA', 'Terminal de Auto Atendimento', 'DLV_ABF', 'Abra Food', 'DLV_ONY', 'Onyo', 'DLV_WZP', 'Whats App', 'DLV_UBR', 'Uber Eats', 'DLV_YAN', 'Yandeh', 'DLV_RAP', 'Rappi', 'DLV_OUT', 'Outros', 'Outros') AS MODALIDADE,
                                     ITV.NRORG,
                                     SUM(TRUNC(ITV.QTPRODVEND * (ITV.VRUNITVEND + NVL(ITV.VRUNITVENDCL,0)),2) - NVL(ITV.VRDESITVEND, 0) + NVL(ITV.VRACRITVEND,0)) AS VALOR_TOTAL
                              FROM VENDA V
                              JOIN ITEMVENDA ITV
                              ON V.CDFILIAL = ITV.CDFILIAL       AND V.CDCAIXA = ITV.CDCAIXA
                              AND V.NRSEQVENDA = ITV.NRSEQVENDA  AND V.NRORG = ITV.NRORG
                              WHERE INSTR(:CDFILIAL, V.CDFILIAL) > 0
                              AND ((INSTR(:CDLOJA, V.CDFILIAL ||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
                              AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                              AND V.IDSITUVENDA = 'O'
                              AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0
                              AND V.NRORG = :NRORG
                              GROUP BY ITV.CDFILIAL, ITV.CDCAIXA, V.IDORIGEMVENDA, ITV.NRSEQVENDA, ITV.NRORG
                            ) 
                      GROUP BY CDFILIAL, MODALIDADE, CDCAIXA, NRORG
                     ) ITEMVENDA
                      ON VENDA.CDFILIAL = ITEMVENDA.CDFILIAL
                      AND VENDA.MODALIDADE = ITEMVENDA.MODALIDADE
                      AND VENDA.NRORG = ITEMVENDA.NRORG
                      GROUP BY VENDA.CDFILIAL, VENDA.NMFILIAL, VENDA.MODALIDADE, VENDA.NROPESSOAS
             ) TAB1
       LEFT JOIN (
                SELECT V.CDFILIAL, '', 
                       DECODE(NVL(V.IDORIGEMVENDA, 'DLV_OUT'), 'DLV_SIT', 'Site/App (Teknisa)', 'DLV_APP', 'Aplicativo', 'DLV_CAL', 'Callcenter', 'DLV_INT', 'Site/Integração', 'DLV_FOS', 'ForSale', 'DLV_SAT', 'ForSale', 'DLV_FNC', 'ForSale', 'DLV_IFO', 'iFood', 'DLV_PJA', 'Pedidos Já', 'DLV_SPO', 'Spoon Rocket', 'DLV_IOS', 'Apple', 'DLV_ADR', 'Android', 'DLV_TAA', 'Terminal de Auto Atendimento', 'DLV_ABF', 'Abra Food', 'DLV_ONY', 'Onyo', 'DLV_WZP', 'Whats App', 'DLV_UBR', 'Uber Eats', 'DLV_YAN', 'Yandeh', 'DLV_RAP', 'Rappi', 'DLV_OUT', 'Outros', 'Outros') AS MODALIDADE,
                       NVL(SUM(NVL(I.VRACRITVEND,0)), 0)AS VALOR_TOTAL, 0
                  FROM ITEMVENDA I, LOJA L, VENDA V
                 WHERE I.CDPRODUTO   = L.CDPRODTAXAENTR AND I.NRORG = L.NRORG
                   AND V.NRSEQVENDA  = I.NRSEQVENDA   AND V.CDCAIXA     = I.CDCAIXA
                   AND V.CDFILIAL    = I.CDFILIAL     AND V.NRORG = I.NRORG
                   AND L.CDLOJA      = V.CDLOJA       AND L.CDFILIAL    = V.CDFILIAL
                   AND L.NRORG = V.NRORG          AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
                   AND L.IDTRATTAXAENTR = 'P'
                   AND ((INSTR(:CDLOJA, L.CDFILIAL||L.CDLOJA) > 0) OR (:TCDLOJA = 'T'))
                   AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                   AND V.IDSITUVENDA = 'O'            AND I.NRORG = :NRORG
                   AND SUBSTR(V.IDORIGEMVENDA, 0, 3) = 'DLV'
                   AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0
                 GROUP BY V.CDFILIAL, V.IDORIGEMVENDA
               ) TAB2
              ON TAB1.CDFILIAL = TAB2.CDFILIAL
             AND TAB1.MODALIDADE = TAB2.MODALIDADE
      ORDER BY TAB1.CDFILIAL
    ";
  
    const GET_FATURAMENTODELIVERY_GERAL_SINTETICO = "
       SELECT TAB1.CDFILIAL || ' - ' || TAB1.NMFILIAL AS CODFILIAL, TAB1.CDFILIAL AS CODIGOFILIAL, 
              TAB1.MODALIDADE AS MODALIDADE,  
              NVL(TAB1.VALOR_TOTAL, 0) - NVL(TAB2.VALOR_TOTAL, 0) AS VRVENDA,
              NVL(TAB2.VALOR_TOTAL, 0) AS VRTXENTREGA, 
              NVL(TAB1.VALOR_TOTAL, 0) AS VRTOTAL, 
              TAB1.NROPESSOAS,
              TRUNC((NVL(TAB1.VALOR_TOTAL, 0))/TAB1.NROPESSOAS, 2) AS TICKETMEDIO
         FROM (SELECT VENDA.CDFILIAL, VENDA.NMFILIAL, VENDA.MODALIDADE, SUM(ITEMVENDA.VALOR_TOTAL) AS VALOR_TOTAL, VENDA.NROPESSOAS AS NROPESSOAS
                 FROM (SELECT CDFILIAL, NMFILIAL, NRORG, MODALIDADE, SUM(NROPESSOAS) AS NROPESSOAS 
                         FROM (SELECT V.CDFILIAL, F.NMFILIAL, V.NRSEQVENDA, 'TODOS' AS MODALIDADE, SUM(NVL(V.NRPESMESAVENDA, 1)) AS NROPESSOAS, V.NRORG, V.CDCAIXA
                                 FROM VENDA V
                                 JOIN FILIAL F
                                   ON V.CDFILIAL = F.CDFILIAL
                                  AND V.NRORG   = F.NRORG
                                WHERE INSTR(:CDFILIAL, V.CDFILIAL) > 0
                                  AND ((INSTR(:CDLOJA, V.CDFILIAL ||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
                                  AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                                  AND V.IDSITUVENDA = 'O'
                                  AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0
                                  AND V.NRORG = :NRORG
                                GROUP BY V.CDFILIAL, F.NMFILIAL, V.NRSEQVENDA, V.NRORG, V.CDCAIXA) 
                        GROUP BY CDFILIAL, NMFILIAL, MODALIDADE, NRORG) VENDA
                  JOIN (SELECT CDFILIAL, MODALIDADE, CDCAIXA, NRORG, SUM(VALOR_TOTAL) AS VALOR_TOTAL FROM (
                          SELECT ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, 'TODOS' AS MODALIDADE, ITV.NRORG,
                                 SUM(TRUNC(ITV.QTPRODVEND * (ITV.VRUNITVEND + NVL(ITV.VRUNITVENDCL,0)),2) - NVL(ITV.VRDESITVEND, 0) + NVL(ITV.VRACRITVEND,0)) AS VALOR_TOTAL
                          FROM VENDA V
                          JOIN ITEMVENDA ITV
                          ON V.CDFILIAL                      = ITV.CDFILIAL
                          AND V.CDCAIXA                      = ITV.CDCAIXA
                          AND V.NRSEQVENDA                   = ITV.NRSEQVENDA
                          AND V.NRORG                        = ITV.NRORG
                          WHERE INSTR(:CDFILIAL, V.CDFILIAL) > 0
                          AND ((INSTR(:CDLOJA, V.CDFILIAL ||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
                          AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                          AND V.IDSITUVENDA = 'O'
                          AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0
                          AND V.NRORG = :NRORG
                          GROUP BY ITV.CDFILIAL, ITV.CDCAIXA, V.IDORIGEMVENDA, ITV.NRSEQVENDA, ITV.NRORG) GROUP BY CDFILIAL, MODALIDADE, CDCAIXA, NRORG
                  ) ITEMVENDA
                 ON VENDA.CDFILIAL = ITEMVENDA.CDFILIAL
                AND VENDA.MODALIDADE = ITEMVENDA.MODALIDADE
                AND VENDA.NRORG = ITEMVENDA.NRORG
              GROUP BY VENDA.CDFILIAL, VENDA.NMFILIAL, VENDA.MODALIDADE, VENDA.NROPESSOAS) TAB1
          LEFT JOIN (SELECT V.CDFILIAL,  '',  'TODOS' AS MODALIDADE, NVL(SUM(NVL(I.VRACRITVEND,0)), 0)AS VALOR_TOTAL, 0
                       FROM ITEMVENDA I, LOJA L, VENDA V
                     WHERE I.CDPRODUTO   = L.CDPRODTAXAENTR
                       AND I.NRORG = L.NRORG                AND V.NRSEQVENDA  = I.NRSEQVENDA
                       AND V.CDCAIXA     = I.CDCAIXA        AND V.CDFILIAL    = I.CDFILIAL
                       AND V.NRORG = I.NRORG                AND L.CDLOJA      = V.CDLOJA
                       AND L.CDFILIAL    = V.CDFILIAL       AND L.NRORG = V.NRORG
                       AND INSTR(:CDFILIAL, V.CDFILIAL) > 0 
                       AND L.IDTRATTAXAENTR = 'P'           AND V.IDSITUVENDA = 'O'
                       AND I.NRORG = :NRORG                 AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0
                       AND ((INSTR(:CDLOJA, L.CDFILIAL||L.CDLOJA) > 0) OR (:TCDLOJA = 'T'))
                       AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                     GROUP BY V.CDFILIAL
                    ) TAB2
                 ON TAB1.CDFILIAL = TAB2.CDFILIAL
                AND TAB1.MODALIDADE = TAB2.MODALIDADE
              ORDER BY TAB1.CDFILIAL
    ";
    
    const GET_FATURAMENTODELIVERY_DIA_ANALITICO = "
       SELECT TO_CHAR(TAB1.DTENTRVENDA, 'DD/MM/YYYY') AS DATA,
            TAB1.CDFILIAL || ' - ' || TAB1.NMFILIAL AS CODFILIAL,
              TAB1.CDFILIAL AS CODIGOFILIAL,
            TAB1.MODALIDADE AS MODALIDADE, 
            NVL(TAB1.VALOR_TOTAL, 0) - NVL(TAB2.VALOR_TOTAL, 0) AS VRVENDA,
            NVL(TAB2.VALOR_TOTAL, 0) AS VRTXENTREGA,
            NVL(TAB1.VALOR_TOTAL, 0) AS VRTOTAL,
            TAB1.NROPESSOAS,
            TRUNC((NVL(TAB1.VALOR_TOTAL, 0))/TAB1.NROPESSOAS, 2) AS TICKETMEDIO
            FROM (SELECT VENDA.DTENTRVENDA,
            VENDA.CDFILIAL,
            VENDA.NMFILIAL,
            VENDA.MODALIDADE,
            SUM(ITEMVENDA.VALOR_TOTAL) AS VALOR_TOTAL,
            VENDA.NROPESSOAS AS NROPESSOAS
           FROM (SELECT DTENTRVENDA, CDFILIAL, NMFILIAL, NRORG, MODALIDADE, SUM(NROPESSOAS) AS NROPESSOAS FROM (SELECT V.DTENTRVENDA,
          V.CDFILIAL,
          F.NMFILIAL,
          V.NRSEQVENDA,
          DECODE(NVL(V.IDORIGEMVENDA, 'DLV_OUT'), 'DLV_SIT', 'Site/App (Teknisa)', 'DLV_APP', 'Aplicativo', 'DLV_CAL', 'Callcenter', 'DLV_INT', 'Site/Integração', 'DLV_FOS', 'ForSale', 'DLV_SAT', 'ForSale', 'DLV_FNC', 'ForSale', 'DLV_IFO', 'iFood', 'DLV_PJA', 'Pedidos Já', 'DLV_SPO', 'Spoon Rocket', 'DLV_IOS', 'Apple', 'DLV_ADR', 'Android', 'DLV_TAA', 'Terminal de Auto Atendimento', 'DLV_ABF', 'Abra Food', 'DLV_ONY', 'Onyo', 'DLV_WZP', 'Whats App', 'DLV_UBR', 'Uber Eats', 'DLV_YAN', 'Yandeh', 'DLV_RAP', 'Rappi', 'DLV_OUT', 'Outros', 'Outros') AS MODALIDADE,
          SUM(NVL(V.NRPESMESAVENDA, 1)) AS NROPESSOAS,
          V.NRORG,
          V.CDCAIXA
        FROM VENDA V
        JOIN FILIAL F
        ON V.CDFILIAL = F.CDFILIAL
        AND V.NRORG   = F.NRORG
        WHERE INSTR(:CDFILIAL, V.CDFILIAL) > 0
        AND ((INSTR(:CDLOJA, V.CDFILIAL
          ||V.CDLOJA) > 0)
        OR (:TCDLOJA  = 'T'))
        AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
        AND V.IDSITUVENDA = 'O'
        AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0 
        AND V.NRORG                                            = :NRORG
        GROUP BY V.DTENTRVENDA,
          V.CDFILIAL,
          F.NMFILIAL,
          V.NRSEQVENDA,
          V.IDORIGEMVENDA,
          V.NRORG,
          V.CDCAIXA) GROUP BY DTENTRVENDA, CDFILIAL, NMFILIAL, MODALIDADE, NRORG) VENDA
       JOIN (SELECT DTENTRVENDA, CDFILIAL, MODALIDADE, CDCAIXA, NRORG, SUM(VALOR_TOTAL) AS VALOR_TOTAL FROM (
               SELECT V.DTENTRVENDA,
                      ITV.CDFILIAL,
                      ITV.CDCAIXA,
                      ITV.NRSEQVENDA,                
                      DECODE(NVL(V.IDORIGEMVENDA, 'DLV_OUT'), 'DLV_SIT', 'Site/App (Teknisa)', 'DLV_APP', 'Aplicativo', 'DLV_CAL', 'Callcenter', 'DLV_INT', 'Site/Integração', 'DLV_FOS', 'ForSale', 'DLV_SAT', 'ForSale', 'DLV_FNC', 'ForSale', 'DLV_IFO', 'iFood', 'DLV_PJA', 'Pedidos Já', 'DLV_SPO', 'Spoon Rocket', 'DLV_IOS', 'Apple', 'DLV_ADR', 'Android', 'DLV_TAA', 'Terminal de Auto Atendimento', 'DLV_ABF', 'Abra Food', 'DLV_ONY', 'Onyo', 'DLV_WZP', 'Whats App', 'DLV_UBR', 'Uber Eats', 'DLV_YAN', 'Yandeh', 'DLV_RAP', 'Rappi', 'DLV_OUT', 'Outros', 'Outros') AS MODALIDADE,
                      ITV.NRORG,
                      SUM(TRUNC(ITV.QTPRODVEND * (ITV.VRUNITVEND + NVL(ITV.VRUNITVENDCL,0)),2) - NVL(ITV.VRDESITVEND, 0) + NVL(ITV.VRACRITVEND,0)) AS VALOR_TOTAL
               FROM VENDA V
               JOIN ITEMVENDA ITV
               ON V.CDFILIAL                      = ITV.CDFILIAL
               AND V.CDCAIXA                      = ITV.CDCAIXA
               AND V.NRSEQVENDA                   = ITV.NRSEQVENDA
               AND V.NRORG                        = ITV.NRORG
               WHERE INSTR(:CDFILIAL, V.CDFILIAL) > 0
               AND ((INSTR(:CDLOJA, V.CDFILIAL
                 ||V.CDLOJA) > 0)
               OR (:TCDLOJA  = 'T'))
               AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
             AND V.IDSITUVENDA = 'O'
             AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0 
             AND V.NRORG = :NRORG
             GROUP BY V.DTENTRVENDA, ITV.CDFILIAL, ITV.CDCAIXA, V.IDORIGEMVENDA, ITV.NRSEQVENDA, ITV.NRORG) GROUP BY DTENTRVENDA, CDFILIAL, MODALIDADE, CDCAIXA, NRORG
          ) ITEMVENDA
          ON VENDA.CDFILIAL = ITEMVENDA.CDFILIAL
          AND VENDA.MODALIDADE = ITEMVENDA.MODALIDADE
          AND VENDA.NRORG = ITEMVENDA.NRORG
          AND VENDA.DTENTRVENDA = ITEMVENDA.DTENTRVENDA
          GROUP BY VENDA.DTENTRVENDA, VENDA.CDFILIAL, VENDA.NMFILIAL, VENDA.MODALIDADE, VENDA.NROPESSOAS) TAB1
       LEFT JOIN
       (SELECT V.DTENTRVENDA,
              V.CDFILIAL, 
              '', 
              DECODE(NVL(V.IDORIGEMVENDA, 'DLV_OUT'), 'DLV_SIT', 'Site/App (Teknisa)', 'DLV_APP', 'Aplicativo', 'DLV_CAL', 'Callcenter', 'DLV_INT', 'Site/Integração', 'DLV_FOS', 'ForSale', 'DLV_SAT', 'ForSale', 'DLV_FNC', 'ForSale', 'DLV_IFO', 'iFood', 'DLV_PJA', 'Pedidos Já', 'DLV_SPO', 'Spoon Rocket', 'DLV_IOS', 'Apple', 'DLV_ADR', 'Android', 'DLV_TAA', 'Terminal de Auto Atendimento', 'DLV_ABF', 'Abra Food', 'DLV_ONY', 'Onyo', 'DLV_WZP', 'Whats App', 'DLV_UBR', 'Uber Eats', 'DLV_YAN', 'Yandeh', 'DLV_RAP', 'Rappi', 'DLV_OUT', 'Outros', 'Outros') AS MODALIDADE,
              NVL(SUM(NVL(I.VRACRITVEND,0)), 0)AS VALOR_TOTAL,
              0
         FROM ITEMVENDA I, LOJA L, VENDA V
       WHERE I.CDPRODUTO   = L.CDPRODTAXAENTR
            AND I.NRORG = L.NRORG
            AND V.NRSEQVENDA  = I.NRSEQVENDA
            AND V.CDCAIXA     = I.CDCAIXA
            AND V.CDFILIAL    = I.CDFILIAL
            AND V.NRORG = I.NRORG
            AND L.CDLOJA      = V.CDLOJA
            AND L.CDFILIAL    = V.CDFILIAL
            AND L.NRORG = V.NRORG
            AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
            AND L.IDTRATTAXAENTR = 'P'
            AND ((INSTR(:CDLOJA, L.CDFILIAL||L.CDLOJA) > 0) OR (:TCDLOJA = 'T'))
            AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
            AND V.IDSITUVENDA = 'O'
            AND I.NRORG = :NRORG
            AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0 
       GROUP BY V.DTENTRVENDA, V.CDFILIAL, V.IDORIGEMVENDA) TAB2
       ON TAB1.CDFILIAL = TAB2.CDFILIAL
       AND TAB1.MODALIDADE = TAB2.MODALIDADE
       AND TAB1.DTENTRVENDA = TAB2.DTENTRVENDA
       ORDER BY TAB1.CDFILIAL, TAB1.DTENTRVENDA
    ";
  
    const GET_FATURAMENTODELIVERY_DIA_SINTETICO = "
       SELECT TO_CHAR(TAB1.DTENTRVENDA, 'DD/MM/YYYY') AS DATA,
            TAB1.CDFILIAL || ' - ' || TAB1.NMFILIAL AS CODFILIAL,
              TAB1.CDFILIAL AS CODIGOFILIAL,
            TAB1.MODALIDADE AS MODALIDADE, 
            NVL(TAB1.VALOR_TOTAL, 0) - NVL(TAB2.VALOR_TOTAL, 0) AS VRVENDA,
            NVL(TAB2.VALOR_TOTAL, 0) AS VRTXENTREGA,
            NVL(TAB1.VALOR_TOTAL, 0) AS VRTOTAL,
            TAB1.NROPESSOAS,
            TRUNC((NVL(TAB1.VALOR_TOTAL, 0))/TAB1.NROPESSOAS, 2) AS TICKETMEDIO
            FROM (SELECT VENDA.DTENTRVENDA,
            VENDA.CDFILIAL,
            VENDA.NMFILIAL,
            VENDA.MODALIDADE,
            SUM(ITEMVENDA.VALOR_TOTAL) AS VALOR_TOTAL,
            VENDA.NROPESSOAS AS NROPESSOAS
           FROM (SELECT DTENTRVENDA, CDFILIAL, NMFILIAL, NRORG, MODALIDADE, SUM(NROPESSOAS) AS NROPESSOAS FROM (SELECT V.DTENTRVENDA,
          V.CDFILIAL,
          F.NMFILIAL,
          V.NRSEQVENDA,
          'TODOS' AS MODALIDADE,
          SUM(NVL(V.NRPESMESAVENDA, 1)) AS NROPESSOAS,
          V.NRORG,
          V.CDCAIXA
        FROM VENDA V
        JOIN FILIAL F
        ON V.CDFILIAL = F.CDFILIAL
        AND V.NRORG   = F.NRORG
        WHERE INSTR(:CDFILIAL, V.CDFILIAL) > 0
        AND ((INSTR(:CDLOJA, V.CDFILIAL
          ||V.CDLOJA) > 0)
        OR (:TCDLOJA  = 'T'))
        AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
        AND V.IDSITUVENDA = 'O'
        AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0 
        AND V.NRORG                                            = :NRORG
        GROUP BY V.DTENTRVENDA,
          V.CDFILIAL,
          F.NMFILIAL,
          V.NRSEQVENDA,
          V.NRORG,
          V.CDCAIXA) GROUP BY DTENTRVENDA, CDFILIAL, NMFILIAL, MODALIDADE, NRORG) VENDA
        JOIN (SELECT DTENTRVENDA, CDFILIAL, MODALIDADE, CDCAIXA, NRORG, SUM(VALOR_TOTAL) AS VALOR_TOTAL FROM (
                SELECT V.DTENTRVENDA,
                       ITV.CDFILIAL,
                       ITV.CDCAIXA,
                       ITV.NRSEQVENDA,                
                       'TODOS' AS MODALIDADE,
                       ITV.NRORG,
                       SUM(TRUNC(ITV.QTPRODVEND * (ITV.VRUNITVEND + NVL(ITV.VRUNITVENDCL,0)),2) - NVL(ITV.VRDESITVEND, 0) + NVL(ITV.VRACRITVEND,0)) AS VALOR_TOTAL
                FROM VENDA V
                JOIN ITEMVENDA ITV
                ON V.CDFILIAL                      = ITV.CDFILIAL
                AND V.CDCAIXA                      = ITV.CDCAIXA
                AND V.NRSEQVENDA                   = ITV.NRSEQVENDA
                AND V.NRORG                        = ITV.NRORG
                WHERE INSTR(:CDFILIAL, V.CDFILIAL) > 0
                AND ((INSTR(:CDLOJA, V.CDFILIAL
                  ||V.CDLOJA) > 0)
                OR (:TCDLOJA  = 'T'))
                AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                AND V.IDSITUVENDA = 'O'
                AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0 
                AND V.NRORG = :NRORG
                GROUP BY V.DTENTRVENDA, ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, ITV.NRORG) GROUP BY DTENTRVENDA, CDFILIAL, MODALIDADE, CDCAIXA, NRORG
        ) ITEMVENDA
        ON VENDA.CDFILIAL = ITEMVENDA.CDFILIAL
        AND VENDA.MODALIDADE = ITEMVENDA.MODALIDADE
        AND VENDA.NRORG = ITEMVENDA.NRORG
        AND VENDA.DTENTRVENDA = ITEMVENDA.DTENTRVENDA
        GROUP BY VENDA.DTENTRVENDA, VENDA.CDFILIAL, VENDA.NMFILIAL, VENDA.MODALIDADE, VENDA.NROPESSOAS) TAB1
          LEFT JOIN
          (SELECT V.DTENTRVENDA,
                 V.CDFILIAL, 
                 '', 
                 'TODOS' AS MODALIDADE,
                 NVL(SUM(NVL(I.VRACRITVEND,0)), 0)AS VALOR_TOTAL,
                 0
            FROM ITEMVENDA I, LOJA L, VENDA V
          WHERE I.CDPRODUTO   = L.CDPRODTAXAENTR
               AND I.NRORG = L.NRORG
               AND V.NRSEQVENDA  = I.NRSEQVENDA
               AND V.CDCAIXA     = I.CDCAIXA
               AND V.CDFILIAL    = I.CDFILIAL
               AND V.NRORG = I.NRORG
               AND L.CDLOJA      = V.CDLOJA
               AND L.CDFILIAL    = V.CDFILIAL
               AND L.NRORG = V.NRORG
               AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
               AND L.IDTRATTAXAENTR = 'P'
               AND ((INSTR(:CDLOJA, L.CDFILIAL||L.CDLOJA) > 0) OR (:TCDLOJA = 'T'))
               AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
               AND V.IDSITUVENDA = 'O'
               AND I.NRORG = :NRORG
               AND INSTR(:MODALIDADE, V.IDORIGEMVENDA) > 0 
          GROUP BY V.DTENTRVENDA, V.CDFILIAL) TAB2
          ON TAB1.CDFILIAL = TAB2.CDFILIAL
          AND TAB1.MODALIDADE = TAB2.MODALIDADE
          AND TAB1.DTENTRVENDA = TAB2.DTENTRVENDA
          ORDER BY TAB1.CDFILIAL, TAB1.DTENTRVENDA
    ";   
  
    const GET_FATURAMENTO_TOTAL_POR_MODALIDADE = "
       SELECT TAB1.CDFILIAL,
       TAB1.CDFILIAL || ' - ' || TAB1.NMFILIAL AS CODFILIAL,
	   TAB1.MODALIDADE AS NMMODALIDADE,
	    NVL(TAB1.VALOR_VENDIDO, 0) + NVL(TAB3.VALOR_TOTAL, 0) AS VALOR_VENDIDO, 
	    NVL(TAB1.VRDESCONTO, 0) AS VRDESCONTO
    FROM (SELECT VENDA.CDFILIAL, VENDA.NMFILIAL, VENDA.MODALIDADE, SUM(ITEMVENDA.VALOR_VENDIDO) AS VALOR_VENDIDO, SUM(ITEMVENDA.VRDESCONTO) AS VRDESCONTO,
                 SUM(ITEMVENDA.VRACRESCIMO) AS VRACRESCIMO, SUM(ITEMVENDA.VRCANCELAMENTO) AS VRCANCELAMENTO, SUM(ITEMVENDA.VALOR_TOTAL) AS VALOR_TOTAL, SUM(ITEMVENDA.QTD_TOTAL) AS QTD_TOTAL,
                 SUM(VENDA.VRREPIQUE) AS VRREPIQUE, SUM(VENDA.NROPESSOAS) AS NROPESSOAS
            FROM (SELECT CDFILIAL, NMFILIAL, NRORG, MODALIDADE, SUM(VRREPIQUE) AS VRREPIQUE, 
                         SUM(NROPESSOAS) AS NROPESSOAS 
                    FROM (WITH FLC AS 
                               (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA, V.NMFILIAL
                                   FROM V_FILIALLOJACAIXA V, LOJA L
                                  WHERE ((INSTR(:CDLOJA, V.CDFILIAL||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
                                    AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
                                    AND V.CDFILIAL = L.CDFILIAL
                                    AND V.CDLOJA = L.CDLOJA)
                            SELECT V.CDFILIAL, FLC.NMFILIAL, V.NRSEQVENDA,
                                 CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                   WHEN 'DLV' THEN 'DELIVERY'
                                   WHEN 'MES' THEN 'MESA'
                                   WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TAA' ELSE 'BALCAO' END) 
                                   WHEN 'TAA' THEN 'TAA'
                                   WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE_THRU' ELSE 'COMANDA' END) 
                                   WHEN 'AJU' THEN 'OUTROS'
                                   ELSE 'OUTROS'
                                 END AS MODALIDADE,
                                 SUM(NVL(V.NRPESMESAVENDA, 1)) AS NROPESSOAS, SUM(NVL(V.VRREPIQUEVENDA, 0)) AS VRREPIQUE, V.NRORG, V.CDCAIXA
                            FROM VENDA V, FLC
                            WHERE V.CDFILIAL = FLC.CDFILIAL
                              AND V.CDCAIXA = FLC.CDCAIXA
                              AND V.CDLOJA = FLC.CDLOJA
                             AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                             AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
                          AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)
                             AND V.NRORG = :NRORG
                             AND V.IDSITUVENDA IN( CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                           WHEN 'DLV' THEN 'O'
                                           WHEN 'MES' THEN 'O'
                                           WHEN 'BAL' THEN 'O'
                                           WHEN 'TAA' THEN 'O'
                                           WHEN 'CMD' THEN 'O'
                                           WHEN 'AJU' THEN V.IDSITUVENDA
                                          END)
                            GROUP BY V.CDFILIAL, FLC.NMFILIAL, V.NRSEQVENDA, V.IDORIGEMVENDA, V.NRORG, V.CDCAIXA
                         ) 
                   GROUP BY CDFILIAL, NMFILIAL, MODALIDADE, NRORG
                 ) VENDA
            JOIN (SELECT VENDAS_OK.CDFILIAL, VENDAS_OK.MODALIDADE, VENDAS_OK.NRORG, NVL(SUM(VENDAS_OK.VALOR_VENDIDO), 0) AS VALOR_VENDIDO, NVL(SUM(VENDAS_OK.VRDESCONTO), 0) AS VRDESCONTO, 
                         NVL(SUM(VENDAS_OK.VRACRESCIMO), 0) AS VRACRESCIMO, NVL(SUM(VENDAS_CANCELAMENTO.VRCANCELAMENTO), 0) AS VRCANCELAMENTO, NVL(SUM(VENDAS_OK.VALOR_TOTAL), 0) AS VALOR_TOTAL, SUM(QTD_TOTAL) AS QTD_TOTAL
                    FROM (SELECT CDFILIAL, MODALIDADE, CDCAIXA, NRORG, SUM(VRDESCONTO) AS VRDESCONTO, SUM(VRACRESCIMO) AS VRACRESCIMO, SUM(VALOR_VENDIDO) AS VALOR_VENDIDO, SUM(VALOR_TOTAL) AS VALOR_TOTAL, SUM(QTD_TOTAL) AS QTD_TOTAL 
                            FROM (
                            WITH FLC AS 
                                       (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA, V.NMFILIAL
                                           FROM V_FILIALLOJACAIXA V, LOJA L
                                          WHERE ((INSTR(:CDLOJA, V.CDFILIAL||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
                                            AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
                                            AND V.CDFILIAL = L.CDFILIAL
                                            AND V.CDLOJA = L.CDLOJA)
                                    SELECT ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA,
                                          CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                             WHEN 'DLV' THEN 'DELIVERY'
                                             WHEN 'MES' THEN 'MESA'
                                             WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TAA' ELSE 'BALCAO' END) 
                                             WHEN 'TAA' THEN 'TAA'
                                             WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE_THRU' ELSE 'COMANDA' END) 
                                             WHEN 'AJU' THEN 'OUTROS'
                                             ELSE 'OUTROS'
                                           END AS MODALIDADE, ITV.NRORG, SUM(TRUNC(NVL(ITV.VRDESITVEND, 0), 2)) AS VRDESCONTO, 
                                          CASE V.IDSITUVENDA WHEN 'C' THEN 0 ELSE SUM(TRUNC(NVL(ITV.VRACRITVEND, 0), 2)) END AS VRACRESCIMO,
                                          CASE V.IDSITUVENDA WHEN 'C' THEN 0 ELSE SUM(TRUNC(ITV.QTPRODVEND * (ITV.VRUNITVEND + NVL(ITV.VRUNITVENDCL,0)),2) - NVL(ITV.VRDESITVEND, 0)) END AS VALOR_VENDIDO,
                                          SUM(TRUNC(ITV.QTPRODVEND * (ITV.VRUNITVEND + NVL(ITV.VRUNITVENDCL,0)),2) - NVL(ITV.VRDESITVEND, 0) + NVL(ITV.VRACRITVEND,0)) AS VALOR_TOTAL,
                                          SUM(ITV.QTPRODVEND) AS QTD_TOTAL 
                                     FROM VENDA V, FLC, ITEMVENDA ITV  
                                    WHERE V.CDFILIAL = FLC.CDFILIAL
                                      AND V.CDCAIXA = FLC.CDCAIXA
                                      AND V.CDLOJA = FLC.CDLOJA
                                      AND V.CDFILIAL = ITV.CDFILIAL
                                      AND V.CDCAIXA = ITV.CDCAIXA
                                      AND V.NRSEQVENDA = ITV.NRSEQVENDA
                                      AND V.NRORG = ITV.NRORG  
                                      AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                                      AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
                          AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)
                                      AND V.NRORG = :NRORG
                                      AND V.IDSITUVENDA IN( CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                           WHEN 'DLV' THEN 'O'
                                           WHEN 'MES' THEN 'O'
                                           WHEN 'BAL' THEN 'O'
                                           WHEN 'TAA' THEN 'O'
                                           WHEN 'CMD' THEN 'O'
                                           WHEN 'AJU' THEN V.IDSITUVENDA
                                          END)
                                    GROUP BY ITV.CDFILIAL, ITV.CDCAIXA, V.IDORIGEMVENDA, ITV.NRSEQVENDA, ITV.NRORG,  V.IDSITUVENDA
                                 ) 
                           GROUP BY CDFILIAL, MODALIDADE, CDCAIXA, NRORG
                 ) VENDAS_OK
       LEFT JOIN (SELECT CDFILIAL, CDCAIXA, MODALIDADE, NRORG, SUM(VRCANCELAMENTO) AS VRCANCELAMENTO
                    FROM (WITH FLC AS 
                                   (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA, V.NMFILIAL
                                       FROM V_FILIALLOJACAIXA V, LOJA L
                                      WHERE ((INSTR(:CDLOJA, V.CDFILIAL||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
                                        AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
                                        AND V.CDFILIAL = L.CDFILIAL
                                        AND V.CDLOJA = L.CDLOJA)
                                SELECT ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, ITV.NRORG,
                                 CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                   WHEN 'DLV' THEN 'DELIVERY'
                                   WHEN 'MES' THEN 'MESA'
                                   WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TAA' ELSE 'BALCAO' END) 
                                   WHEN 'TAA' THEN 'TAA'
                                   WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE_THRU' ELSE 'COMANDA' END) 
                                   WHEN 'AJU' THEN 'OUTROS'
                                   ELSE 'OUTROS'
                                 END AS MODALIDADE,
                                 SUM(TRUNC(ITV.QTPRODVEND * (ITV.VRUNITVEND + NVL(ITV.VRUNITVENDCL,0)),2) + NVL(ITV.VRACRITVEND,0) ) AS VRCANCELAMENTO,
                                 SUM(ITV.QTPRODVEND) AS QTD_TOTAL 
                            FROM VENDA V, FLC, ITEMVENDA ITV                                 
                           WHERE V.CDFILIAL = ITV.CDFILIAL
                             AND V.CDCAIXA = ITV.CDCAIXA
                             AND V.NRSEQVENDA = ITV.NRSEQVENDA
                             AND V.NRORG = ITV.NRORG
                             AND V.CDFILIAL = FLC.CDFILIAL
                             AND V.CDCAIXA = FLC.CDCAIXA
                             AND V.CDLOJA = FLC.CDLOJA
                             AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                             AND V.IDSITUVENDA = 'C'
                             AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
                          AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)
                             AND V.NRORG = :NRORG
                           GROUP BY ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, ITV.NRORG, V.IDORIGEMVENDA
                           
                           UNION
                           
                           SELECT ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, ITV.NRORG,
                                 CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                   WHEN 'DLV' THEN 'DELIVERY'
                                   WHEN 'MES' THEN 'MESA'
                                   WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TAA' ELSE 'BALCAO' END) 
                                   WHEN 'TAA' THEN 'TAA'
                                   WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE_THRU' ELSE 'COMANDA' END) 
                                   WHEN 'AJU' THEN 'OUTROS'
                                   ELSE 'OUTROS'
                                 END AS MODALIDADE,
                                 SUM(TRUNC(ITV.QTPRODVENDC * (ITV.VRUNITVENDC + NVL(ITV.VRUNITVENCLC,0)),2) + NVL(ITV.VRACRITVENDC,0) ) AS VRCANCELAMENTO,
                                 SUM(ITV.QTPRODVENDC) AS QTD_TOTAL 
                            FROM VENDA V, (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA
                               FROM V_FILIALLOJACAIXA V, LOJA L
                              WHERE ((INSTR(:CDLOJA, V.CDFILIAL ||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
                                AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
                                AND V.CDFILIAL = L.CDLOJA
                                AND V.CDLOJA = L.CDLOJA) FLC, ITVENDACAN ITV
                           WHERE V.CDFILIAL = ITV.CDFILIAL
                             AND V.CDCAIXA = ITV.CDCAIXA
                             AND V.NRSEQVENDA = ITV.NRSEQVENDA
                             AND V.NRORG = ITV.NRORG
                             AND V.CDFILIAL = FLC.CDFILIAL
                             AND V.CDCAIXA = FLC.CDCAIXA
                             AND V.CDLOJA = FLC.CDLOJA
                             AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN                                 
                             AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
                          AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)
                             AND V.NRORG = :NRORG
                           GROUP BY ITV.CDFILIAL, ITV.CDCAIXA, ITV.NRSEQVENDA, ITV.NRORG, V.IDORIGEMVENDA
                         ) 
                   GROUP BY CDFILIAL, CDCAIXA, MODALIDADE, NRORG
                 ) VENDAS_CANCELAMENTO
                ON VENDAS_OK.CDFILIAL = VENDAS_CANCELAMENTO.CDFILIAL
               AND VENDAS_OK.CDCAIXA = VENDAS_CANCELAMENTO.CDCAIXA
               AND VENDAS_OK.MODALIDADE = VENDAS_CANCELAMENTO.MODALIDADE
               AND VENDAS_OK.NRORG = VENDAS_CANCELAMENTO.NRORG
             GROUP BY VENDAS_OK.CDFILIAL, VENDAS_OK.MODALIDADE, VENDAS_OK.NRORG
            ) ITEMVENDA
           ON VENDA.CDFILIAL = ITEMVENDA.CDFILIAL
          AND VENDA.MODALIDADE = ITEMVENDA.MODALIDADE
          AND VENDA.NRORG = ITEMVENDA.NRORG
  GROUP BY VENDA.CDFILIAL, VENDA.NMFILIAL, VENDA.MODALIDADE) TAB1
  LEFT JOIN (SELECT TB2.CDFILIAL,'', TB2.MODALIDADE, SUM(TB2.VALOR_TOTAL) AS VALOR_TOTAL, 0
             FROM ( SELECT V.CDFILIAL,'', 
                      CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                         WHEN 'DLV' THEN 'DELIVERY'
                         WHEN 'MES' THEN 'MESA'
                         WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TAA' ELSE 'BALCAO' END) 
                         WHEN 'TAA' THEN 'TAA'
                         WHEN 'CMD' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'THR' THEN 'DRIVE_THRU' ELSE 'COMANDA' END) 
                         WHEN 'AJU' THEN 'OUTROS'
                         ELSE 'OUTROS'
                       END AS MODALIDADE,
                       SUM(I.QTPRODVEND) AS QTD_TOTAL ,
                       NVL(SUM(NVL(I.VRACRITVEND,0)), 0) AS VALOR_TOTAL, 0
                    FROM ITEMVENDA I, (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA, L.CDPRODTAXASERV, L.IDTRATTAXASERV
                           FROM V_FILIALLOJACAIXA V, LOJA L
                          WHERE ((INSTR(:CDLOJA, V.CDFILIAL ||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
                            AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
                            AND V.CDFILIAL = L.CDFILIAL
                            AND V.CDLOJA = L.CDLOJA) FLC, VENDA V
                    WHERE V.NRSEQVENDA  = I.NRSEQVENDA      
                     AND V.CDCAIXA     = I.CDCAIXA
                     AND V.CDFILIAL    = I.CDFILIAL                                                                  
                     AND V.CDFILIAL = FLC.CDFILIAL
                     AND V.CDCAIXA = FLC.CDCAIXA
                     AND V.CDLOJA = FLC.CDLOJA                                
                     AND I.CDPRODUTO   = FLC.CDPRODTAXASERV                               
                     AND FLC.IDCOMISVENDA IN ('S', 'G')      
                     AND FLC.IDTRATTAXASERV = 'P'                             
                     AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN
                     AND V.IDSITUVENDA = 'O'               
                     AND SUBSTR(V.IDORIGEMVENDA, 0, 3) <> 'DLV'
                     AND I.NRORG = :NRORG                      
                     AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
                          AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)
                    GROUP BY V.CDFILIAL, V.IDORIGEMVENDA) TB2
               GROUP BY TB2.CDFILIAL, TB2.MODALIDADE
            ) TAB2
           ON TAB1.CDFILIAL = TAB2.CDFILIAL
          AND TAB1.MODALIDADE = TAB2.MODALIDADE
    LEFT JOIN (SELECT V.CDFILIAL,  '', 
                      CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
                                   WHEN 'DLV' THEN 'DELIVERY'
                                   WHEN 'MES' THEN 'MESA'
                                   WHEN 'BAL' THEN 'BALCAO'
                                   WHEN 'TAA' THEN 'TAA'
                                   WHEN 'CMD' THEN 'COMANDA'
                                   WHEN 'AJU' THEN 'OUTROS'
                                   ELSE 'OUTROS'
                                 END AS MODALIDADE,
                                 SUM(I.QTPRODVEND) AS QTD_TOTAL, 
                      NVL(SUM(NVL(I.VRACRITVEND,0))- SUM(NVL(V.VRREPIQUEVENDA,0)), 0)AS VALOR_TOTAL, 0
                 FROM ITEMVENDA I, (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, V.CDCAIXA, L.IDCOMISVENDA, L.CDPRODTAXASERV, L.IDTRATTAXASERV, L.IDTRATTAXAENTR
                                   FROM V_FILIALLOJACAIXA V, LOJA L
                                  WHERE ((INSTR(:CDLOJA, V.CDFILIAL ||V.CDLOJA) > 0) OR (:TCDLOJA  = 'T'))
                                    AND INSTR(:CDFILIAL, V.CDFILIAL) > 0
                                    AND V.CDFILIAL = L.CDFILIAL
                                    AND V.CDLOJA = L.CDLOJA) FLC, VENDA V
                WHERE V.NRSEQVENDA  = I.NRSEQVENDA      
                  AND V.CDCAIXA     = I.CDCAIXA
                  AND V.CDFILIAL    = I.CDFILIAL                                                                  
                  AND V.CDFILIAL = FLC.CDFILIAL
                  AND V.CDCAIXA = FLC.CDCAIXA
                  AND V.CDLOJA = FLC.CDLOJA                                
                  AND I.CDPRODUTO   = FLC.CDPRODTAXASERV        
                  AND FLC.IDTRATTAXAENTR = 'P'              
                  AND SUBSTR(V.IDORIGEMVENDA, 0, 3) = 'DLV'                                            
                  AND V.IDSITUVENDA = 'O'                      
                  AND (INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 0, 3) ) > 0 OR INSTR(:MODALIDADE, SUBSTR(V.IDORIGEMVENDA, 5, 7) ) > 0) 
                          AND V.IDORIGEMVENDA <> (CASE :FLAGBALTAA WHEN 'S' THEN 'BAL_AUT' ELSE 'ZZZZZZ' END)
                  AND V.DTENTRVENDA BETWEEN :DATAINI AND :DATAFIN                       
                GROUP BY V.CDFILIAL, SUBSTR(V.IDORIGEMVENDA, 0, 3)
              ) TAB3
             ON TAB1.CDFILIAL = TAB3.CDFILIAL
            AND TAB1.MODALIDADE = TAB3.MODALIDADE
          ORDER BY TAB1.CDFILIAL
    ";   
}
